@@ -4,7 +4,7 @@ StreamFinder::RadioNet - Fetch actual raw streamable URLs from radio-station web
 
 =head1 AUTHOR
 
-This module is Copyright (C) 2017-2020 by
+This module is Copyright (C) 2017-2021 by
 
 Jim Turner, C<< <turnerjw784 at yahoo.com> >>
 		
@@ -103,13 +103,18 @@ One or more streams can be returned for each station.
 
 =over 4
 
-=item B<new>(I<ID>|I<url> [, "debug" [ => 0|1|2 ]])
+=item B<new>(I<ID>|I<url> [, I<-secure> [ => 0|1 ]] [, I<-debug> [ => 0|1|2 ]])
 
 Accepts a Radio.net station ID or URL and creates and returns a new station 
 object, or I<undef> if the URL is not a valid Radio.net station or no 
 streams are found.  The URL can be the full URL, 
 ie. https://www.radio.net/s/B<station-id>, or just I<station-id>.
 
+The optional I<-secure> argument can be either 0 or 1 (I<false> or I<true>).  If 1 
+then only secure ("https://") streams will be returned.
+
+DEFAULT I<-secure> is 0 (false) - return all streams (http and https).
+
 =item $station->B<get>()
 
 Returns an array of strings representing all stream URLs found.
@@ -250,7 +255,7 @@ L<http://search.cpan.org/dist/StreamFinder-RadioNet/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2017-2020 Jim Turner.
+Copyright 2017-2021 Jim Turner.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the the Artistic License (2.0). You may obtain a
@@ -340,12 +345,16 @@ sub new
 	push (@userAgentOps, 'agent', 'Mozilla/5.0 (X11; Linux x86_64; rv:68.0) Gecko/20100101 Firefox/68.0')
 			unless (defined $uops{'agent'});
 	$uops{'timeout'} = 10  unless (defined $uops{'timeout'});
+	$uops{'secure'} = 0    unless (defined $uops{'secure'});
 	$DEBUG = $uops{'debug'}  if (defined $uops{'debug'});
 
 	while (@_) {
 		if ($_[0] =~ /^\-?debug$/o) {
 			shift;
 			$DEBUG = (defined($_[0]) && $_[0] =~/^[0-9]$/) ? shift : 1;
+		} elsif ($_[0] =~ /^\-?secure$/o) {
+			shift;
+			$uops{'secure'} = (defined $_[0]) ? shift : 1;
 		}
 	}	
 
@@ -397,12 +406,18 @@ sub new
 	print STDERR "-2: icon=".$self->{'iconurl'}."= title=".$self->{'title'}."= image=".$self->{'imageurl'}."=\n"  if ($DEBUG);
 	$self->{'cnt'} = 0;
 	while ($html =~ s#\"streamUrl\"\:\"([^\"]+)\"##s) {
-		push @{$self->{'streams'}}, $1;
-		$self->{'cnt'}++;
+		my $one = $1;
+		unless ($uops{'secure'} && $one !~ /^https/o) {
+			push @{$self->{'streams'}}, $one;
+			$self->{'cnt'}++;
+		}
 	}
 	while ($html =~ s#\{\"url\"\:\"([^\"]+)\"##s) {
-		push @{$self->{'streams'}}, $1;
-		$self->{'cnt'}++;
+		my $one = $1;
+		unless ($uops{'secure'} && $one !~ /^https/o) {
+			push @{$self->{'streams'}}, $one;
+			$self->{'cnt'}++;
+		}
 	}
 	$self->{'total'} = $self->{'cnt'};
 
