@@ -103,7 +103,7 @@ One or more stream URLs can be returned for each podcast.
 
 =over 4
 
-=item B<new>(I<ID>|I<url> [, I<-debug> [ => 0|1|2 ] ... ])
+=item B<new>(I<ID>|I<url> [, I<-secure> [ => 0|1 ]] [, I<-debug> [ => 0|1|2 ]])
 
 Accepts a www.sermonaudio.com podcast (sermon) ID or URL and creates and returns a 
 a new podcast object, or I<undef> if the URL is not a valid podcast, or no streams 
@@ -111,6 +111,11 @@ are found.  The URL can be the full URL, ie.
 https://www.sermonaudio.com/sermoninfo.asp?SID=B<podcast-id>, or just 
 I<podcast-id>.
 
+The optional I<-secure> argument can be either 0 or 1 (I<false> or I<true>).  If 1 
+then only secure ("https://") streams will be returned.
+
+DEFAULT I<-secure> is 0 (false) - return all streams (http and https).
+
 =item $podcast->B<get>()
 
 Returns an array of strings representing all stream URLs found.
@@ -335,12 +340,16 @@ sub new
 	push (@userAgentOps, 'agent', 'Mozilla/5.0 (X11; Linux x86_64; rv:68.0) Gecko/20100101 Firefox/68.0')
 			unless (defined $uops{'agent'});
 	$uops{'timeout'} = 10  unless (defined $uops{'timeout'});
+	$uops{'secure'} = 0    unless (defined $uops{'secure'});
 	$DEBUG = $uops{'debug'}  if (defined $uops{'debug'});
 
 	while (@_) {
 		if ($_[0] =~ /^\-?debug$/o) {
 			shift;
 			$DEBUG = (defined($_[0]) && $_[0] =~/^[0-9]$/) ? shift : 1;
+		} elsif ($_[0] =~ /^\-?secure$/o) {
+			shift;
+			$uops{'secure'} = (defined $_[0]) ? shift : 1;
 		}
 	}
 
@@ -384,7 +393,7 @@ sub new
 	foreach my $tag ('og:audio:secure_url" content=', 'og:audio:url" content=', 'og:audio" content=') {
 		if ($html =~ s#\"$tag\"([^\"]+)\"##gso) {
 			my $audiourl = $1;
-			unless ($dups{$audiourl}) {
+			unless (defined($dups{$audiourl}) || ($uops{'secure'} && $audiourl !~ /^https/o)) {
 				push @{$self->{'streams'}}, $audiourl;
 				$self->{'cnt'}++;
 				$dups{$audiourl} = 1;
